@@ -23,10 +23,13 @@
 import click
 
 from zilliqaetl.cli.export_ds_blocks import export_ds_blocks
+from zilliqaetl.cli.export_tx_blocks import export_tx_blocks
+from zilliqaetl.cli.get_ds_block_range_for_date import get_ds_block_range_for_date
+from zilliqaetl.cli.get_tx_block_range_for_date import get_tx_block_range_for_date
 
 
 @click.group()
-@click.version_option(version='0.0.1')
+@click.version_option(version='0.0.2')
 @click.pass_context
 def cli(ctx):
     pass
@@ -34,3 +37,8 @@ def cli(ctx):
 
 # export
 cli.add_command(export_ds_blocks, "export_ds_blocks")
+cli.add_command(export_tx_blocks, "export_tx_blocks")
+
+# utils
+cli.add_command(get_ds_block_range_for_date, "get_ds_block_range_for_date")
+cli.add_command(get_tx_block_range_for_date, "get_tx_block_range_for_date")
